<?php
/**
 * @brief		Admin CP Group Form
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Members Shop
 * @since		16 Mar 2018
 */

namespace IPS\membersshop\extensions\core\GroupForm;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Admin CP Group Form
 */
class _membersshop
{
	/**
	 * Process Form
	 *
	 * @param	\IPS\Helpers\Form		$form	The form
	 * @param	\IPS\Member\Group		$group	Existing Group
	 * @return	void
	 */
	public function process( &$form, $group )
	{
		try
		{
			$perms = \IPS\membersshop\Groups::load( $group->g_id, 'group_id' );
		}
		catch( \Exception $e )
		{
			$perms = FALSE;
		}
		
		$form->addHeader( 'ms_banking' );
		$form->add( new \IPS\Helpers\Form\YesNo( 'ms_can_bank', $perms ? $perms->can_bank : 0, FALSE, array( 'togglesOn' => array( 'ms_bank_interest', 'ms_deposit_cost', 'ms_max_points' ) ) ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_bank_interest', $perms ? $perms->bank_interest : 0, FALSE, array(), NULL, NULL, '%', 'ms_bank_interest' ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_deposit_cost', $perms ? $perms->deposit_cost : 10, FALSE, array(), NULL, NULL, '%', 'ms_deposit_cost' ) );
		$form->addHeader('ms_bonus_points');
		if( $perms AND $perms->daily_points ){ $toggle = 1; }else{ $toggle = 0; }
		$form->add( new \IPS\Helpers\Form\YesNo( 'ms_activate_daily', $toggle, FALSE, array('togglesOn' => array( 'ms_daily_points' ) ) ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_daily_points', $perms ? $perms->daily_points : 0, FALSE, array( ), NULL, NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_per_day' ), 'ms_daily_points' ) );
        if( $perms AND $perms->weekly_points ){ $toggle = 1; }else{ $toggle = 0; }
		$form->add( new \IPS\Helpers\Form\YesNo( 'ms_activate_weekly', $toggle, FALSE, array('togglesOn' => array( 'ms_weekly_points' ) ) ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_weekly_points', $perms ? $perms->weekly_points : 0, FALSE, array( ), NULL, NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_per_week' ), 'ms_weekly_points' ) );
        if( $perms AND $perms->monthly_points){ $toggle = 1; }else{ $toggle = 0; }
		$form->add( new \IPS\Helpers\Form\YesNo( 'ms_activate_monthly', $toggle, FALSE, array('togglesOn' => array( 'ms_monthly_points' ) ) ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_monthly_points', $perms ? $perms->monthly_points : 0, FALSE, array( ), NULL, NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_per_month' ), 'ms_monthly_points' ) );
	}

	/**
	 * Save
	 *
	 * @param	array				$values	Values from form
	 * @param	\IPS\Member\Group	$group	The group
	 * @return	void
	 */
	public function save( $values, &$group )
	{
		try
		{
			$perms = \IPS\membersshop\Groups::load( $group->g_id, 'group_id' );
		}
		catch( \Exception $e )
		{
			$perms = new \IPS\membersshop\Groups;
		}

		$perms->group_id = $group->g_id;

		if( !$values['ms_can_bank'] )
		{
			$perms->can_bank = $values['ms_can_bank'];
			$perms->bank_interest = 0;
			$perms->deposit_cost = 0;
		}
		else
		{
			$perms->can_bank = $values['ms_can_bank'];
			$perms->bank_interest = $values['ms_bank_interest'];	
			$perms->deposit_cost = $values['ms_deposit_cost'];	
		}

		if( !$values['ms_activate_daily'] )
		{
			$perms->daily_points = 0;	
		}
		else
		{
			$perms->daily_points = $values['ms_daily_points'];	
		}

		if( !$values['ms_activate_weekly'] )
		{
			$perms->weekly_points = 0;	
		}
		else
		{
			$perms->weekly_points = $values['ms_weekly_points'];	
		}

		if( !$values['ms_activate_monthly'] )
		{
			$perms->monthly_points = 0;	
		}
		else
		{
			$perms->monthly_points = $values['ms_monthly_points'];	
		}

		$perms->save();
	}
}