<?php
/**
 * @brief		Profile extension: msProfile
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Members Shop
 * @since		21 Jun 2021
 */

namespace IPS\membersshop\extensions\core\Profile;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * @brief	Profile extension: msProfile
 */
class _msProfile
{
	protected $member;
	
	public function __construct( \IPS\Member $member )
	{
		$this->member = $member;
	}

	/**
	 * Is there content to display?
	 *
	 * @return	bool
	 */
	public function showTab()
	{
		if( \IPS\Settings::i()->ms_profile_tab )
		{
			return TRUE;
		}

		return FALSE;
	}

	/**
	 * Display
	 *
	 * @return	string
	 */
	public function render()
	{
		$url = $this->member->url()->setQueryString( 'tab', 'node_membersshop_msProfile' );

		if( \IPS\Request::i()->sortBy )
		{
			$url = $url->setQueryString( 'sortBy', \IPS\Request::i()->sortBy );
		}

		$where = array( array( 'member_id=?', $this->member->member_id ) );
		if( \IPS\Settings::i()->ms_profile_tab_not_redeemed )
		{
			$where[] = array( 'redeemed=?', 0 );
		}
		else
		{
			$where[] = array( 'redeemed=?', 1 );
		}

		$table = new \IPS\Helpers\Table\Db( 'membersshop_purchases', $url, $where );
		if( \IPS\Settings::i()->ms_myitems_view_set == 0 )
		{
			$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop', 'front' ), 'myitemsrows' );
		}
		else
		{
			if( \IPS\Settings::i()->ms_grid_style == 0 )
			{
				$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop', 'front' ), 'myitemsrowsGridMini' );
			}
			else
			{
				$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop', 'front' ), 'myitemsrowsGrid' );
			}	
		}

		$table->limit = \IPS\Settings::i()->ms_myitems_table_limit;
		$table->sortOptions = array( 'name' => 'name', 'item_id' => 'item_id', 'price' => 'price', 'time_date' => 'time_date' );

		switch( \IPS\Request::i()->sortBy )
		{
			case 'name':
				$table->sortBy = 'name';
				$table->sortDirection = 'asc';
				break;
			case 'price_low':
				$table->sortBy = 'price';
				$table->sortDirection = 'asc';
				break;
			case 'price_high':
				$table->sortBy = 'price';
				$table->sortDirection = 'desc';
				break;
			case 'item_id':
				$table->sortBy = 'item_id';
				$table->sortDirection = 'asc';
				break;
			default:
				$table->sortBy = 'time_date';
				$table->sortDirection = 'desc';
				$url = $url->setQueryString( 'sortBy', NULL );
				break;
		}

		$title = \IPS\Member::loggedIn()->language()->addToStack('ms_myitems');
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('ms_myitems');

		return \IPS\Theme::i()->getTemplate( 'shop', 'membersshop', 'front' )->template( (string) $table, $this->member, $title );
	}
}