<?php


namespace IPS\membersshop\modules\admin\bank;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * bank
 */
class _bank extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{		
		$table = new \IPS\Helpers\Table\Db( 'membersshop_bank', \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank' ) );
		$table->langPrefix = 'ms__';
		$table->include = array( 'id', 'member_id', 'points' );
		$table->exclude = array( 'id' );
		$table->limit = 10;
		$table->mainColumn = 'member_id';
		$table->sortBy = $table->sortBy ?: 'points';
		$table->sortDirection = $table->sortDirection ?: 'desc';
	    $table->parsers = array(
			'member_id' => function( $val, $row )
			{
				$member = \IPS\Member::load( $val );
				return \IPS\Theme::i()->getTemplate( 'global', 'core' )->userPhoto( $member, 'tiny' ) . ' ' . $member->link();
				
			},
			'points' => function( $val, $row )
			{
				$points = number_format( $val );
				return $points;
			}
		);
		
		$table->rowButtons = function( $row )
		{
			$return = array( 'edit'	=> array(
				'title'	=> 'Edit',
				'icon'	=> 'edit',
				'link'	=> \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank&do=editmembersbank&id=' ) . $row['id'],
				'data'	=> array( 'ipsDialog' => '', 'ipsDialog-size' => 'medium', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('ms_editing_bank_points') )
			)	);
			$return['transactions'] = array(
			    'title'	=> 'ms_view_transactions',
				'icon'	=> 'credit-card',
				'link'	=> \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank&do=viewtransactions&id=' ) . $row['member_id'],
				'data'	=> array( 'ipsDialog' => '', 'ipsDialog-size' => 'narrow' )
			);
			return $return;
		};
		
		/*
		\IPS\Output::i()->sidebar['actions']['custom'] = array(
		    'primary'   => TRUE,
			'icon'		=> 'area-chart',
			'title'		=> 'ms_view_chart',
			'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank&do=graph' ),
			'data'		=> array( 'ipsDialog' => '' )
		);
		*/
		
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('menu__membersshop_bank');
		\IPS\Output::i()->output = (string) $table;
	}
	
	protected function editmembersbank()
	{
		$id = \IPS\Request::i()->id;
		$bankPoints = \IPS\membersshop\Bank::load( $id );
		$form = new \IPS\Helpers\Form;
		$form->add( new \IPS\Helpers\Form\Number( 'ms_edit_members_bank', $bankPoints->points, FALSE, array( ) ) );
		
		if( $values = $form->values() )
        {
	        $bankPoints->points = $values['ms_edit_members_bank'];
			$bankPoints->save();
	        \IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank' ), 'saved' );
        }

		\IPS\Output::i()->output = $form;
	}
	
	protected function viewtransactions()
	{
		$id = \IPS\Request::i()->id;
		
		$table = new \IPS\Helpers\Table\Db( 'membersshop_bank_transactions', \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=bank&do=viewtransactions&id='.$id.'' ) );
		$table->langPrefix = 'ms__';
		$table->include = array( 'id', 'member_id', 'transaction', 'amount', 'time_date' );
		$table->exclude = array( 'id', 'member_id' );
		$table->mainColumn = 'member_id';
		$table->sortBy = $table->sortBy ?: 'id';
		$table->sortDirection = $table->sortDirection ?: 'asc';
		$table->where[] = array( 'member_id=?', $id );
		$table->limit = 10;
		$table->parsers = array(
			'time_date'	=> function( $val, $row )
			{
				$date	= date('F j, Y, G:i', $val);
				return $date;
			},
			'amount' => function( $val, $row )
			{
				$amount = number_format( $val );
				return $amount;
			},
			'transaction' => function( $val, $row )
			{
				if( $val == 0 )
				{
					return \IPS\Member::loggedIn()->language()->addToStack( 'ms_deposit' );
				}
				else
				{
					return \IPS\Member::loggedIn()->language()->addToStack( 'ms_withdrawal' );
				}
			}
		);
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'menu__membersshop_bank_transactions' );
		\IPS\Output::i()->output = (string) $table;
	}
}