<?php

namespace IPS\membersshop\modules\admin\bank;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _transactions extends \IPS\Dispatcher\Controller
{
	public static $csrfProtected = TRUE;

	protected function manage()
	{
		\IPS\Dispatcher::i()->checkAcpPermission( 'transactions_manage' );

		$table = new \IPS\Helpers\Table\Db( 'membersshop_bank_transactions', \IPS\Http\Url::internal( 'app=membersshop&module=bank&controller=transactions' ) );
		$table->joins = array( array( 'from' => 'core_members', 'where' => 'core_members.member_id=membersshop_bank_transactions.member_id' ) );
		$table->include = array( 'id', 'member_id', 'amount', 'transaction', 'charge', 'time_date', 'balance' );
		$table->exclude = array( 'id' );
		$table->mainColumn = 'member_id';

		$table->langPrefix = 'ms__';

		$table->sortBy = $table->sortBy ?: 'time_date';
		$table->sortDirection = $table->sortDirection ?: 'DESC';

		$table->quickSearch = 'name';

		$options = array(
			0 => \IPS\Member::loggedIn()->language()->addToStack( 'ms_deposit' ),
			1 => \IPS\Member::loggedIn()->language()->addToStack( 'ms_withdrawal' )
		);
		$table->advancedSearch = array(
			'member_id'		=> \IPS\Helpers\Table\SEARCH_MEMBER,
			'amount' 		=> \IPS\Helpers\Table\SEARCH_NUMERIC,
			'transaction' 	=> array( \IPS\Helpers\Table\SEARCH_SELECT, array( 'options' => $options ) ),
			'time_date'		=> \IPS\Helpers\Table\SEARCH_DATE_RANGE,
		);

		$table->parsers = array(
			'time_date'	=> function( $val, $row )
			{
				$date	= \IPS\DateTime::ts( $val );
				return $date->localeDate() . ' ' . $date->localeTime( FALSE ) ;
			},
			'member_id' => function( $val, $row )
			{
				$member_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['member_id'] . "'>$member_id->name</a>";
				
			},
			'amount' => function( $val, $row )
			{
				$amount = number_format( $val );
				return $amount;
			},
			'balance' => function( $val, $row )
			{
				$balance = number_format( $val );
				return $balance;
			},
			'charge' => function( $val, $row )
			{
				$charge = number_format( $val );
				if( $charge == 0 )
				{
					return 'Free';
				}
				else
				{
					return $charge;
				}
			},
			'transaction' => function( $val, $row )
			{
				if( $val == 0 )
				{
					return \IPS\Member::loggedIn()->language()->addToStack( 'ms_deposit' );
				}
				else
				{
					return \IPS\Member::loggedIn()->language()->addToStack( 'ms_withdrawal' );
				}
			}
		);

		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'menu__membersshop_bank_transactions' );
		\IPS\Output::i()->output = (string) $table;
	}
}