<?php


namespace IPS\membersshop\modules\admin\points;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * calendars
 */
class _calendars extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('module__membersshop_points_calendar');	   
		
		\IPS\Output::i()->sidebar['actions']['misc'] = array(
			'icon'		=> 'superpowers',
			'title'		=> 'ms_misc',
			'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=misc' ),
			'data'		=> array( )
		);	
		
		if( \IPS\Settings::i()->clubs AND !\IPS\Settings::i()->ms_disable_clubs_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['clubs'] = array(
				'icon'		=> 'users',
				'title'		=> 'ms_clubs',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=clubs' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'gallery') AND !\IPS\Settings::i()->ms_disable_gallery_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['gallery'] = array(
				'icon'		=> 'image',
				'title'		=> 'ms_gallery',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=gallerys' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'downloads') AND !\IPS\Settings::i()->ms_disable_downloads_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['downloads'] = array(
				'icon'		=> 'download',
				'title'		=> 'ms_downloads',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=downloads' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'forums') AND !\IPS\Settings::i()->ms_disable_forum_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['add'] = array(
				'icon'		=> 'comment-o',
				'title'		=> 'ms_forums',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=forums' ),
				'data'		=> array( )
			);
		}
			
		if( \IPS\Application::appIsEnabled( 'calendar') AND !\IPS\Settings::i()->ms_disable_calendar_hooks )
		{       
	        $matrix = new \IPS\Helpers\Form\Matrix;
        
        	$matrix->manageable = FALSE;
	        $matrix->widths = array( 'label' => 30 );
	        $matrix->langPrefix = 'ms_calendar_';
        
	        $matrix->columns = array(
				'label'	=> function( $key, $value, $data )
				{
					return $value;
				}
			);
                
	        $matrix->columns[ 'ms_points_event' ] = function( $key, $value, $data ) 
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'event_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};                
			$matrix->columns[ 'ms_points_review' ] = function( $key, $value, $data )
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'review_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};
			$matrix->columns[ 'ms_points_comment' ] = function( $key, $value, $data )
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'comment_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};

	        $rows = array();
		
			foreach( \IPS\calendar\Calendar::roots( NULL ) AS $root )
			{
				self::populatePermissionMatrix( $rows, $root );
			}
		
			$matrix->rows = $rows;

	        if( $values = $matrix->values() )
   		    {
				if( !empty( $matrix->changedRows ) )
				{
					foreach( $matrix->changedRows as $key )
					{
						try
						{
							$points = \IPS\membersshop\Calendar\Points::load( $key, 'c_id' );
						}
						catch ( \OutOfRangeException $e )
						{
						    $points = new \IPS\membersshop\Calendar\Points;
							$points->c_id = $key;
						}
						$points->points_for_event = (int) $values[ $key ]['ms_points_event'];
						$points->points_for_review = (int) $values[ $key ]['ms_points_review'];
						$points->points_for_comment = (int) $values[ $key ]['ms_points_comment'];
						$points->save();
					}
				}
	        }
			
	        \IPS\Output::i()->output = $matrix;
		}
		else
		{
			\IPS\Output::i()->output = '<div class="ipsPad ipsBox">You must have the calendar app installed and the disable gallery settings switched off to use this feature</div>';
		}
	}
	
	public static function populatePermissionMatrix( &$rows, $calendar, $level=0 )
	{
		$rows[ $calendar->_id ] = array( '_level' => $level, 'label' => $calendar->_title );
        try
		{
			$points = \IPS\membersshop\Calendar\Points::load( $calendar->_id, 'c_id' );
			$pointsPerEvent = $points->points_for_event;
			$pointsPerReview = $points->points_for_review;
			$pointsPerComment = $points->points_for_comment;
        }
		catch ( \OutOfRangeException $e )
		{
			$pointsPerEvent = 0;
			$pointsPerReview = 0;
			$pointsPerComment = 0;
		}
		$rows[ $calendar->_id ]['ms_points_event']   = $pointsPerEvent;
    	$rows[ $calendar->_id ]['ms_points_review']   = $pointsPerReview;
		$rows[ $calendar->_id ]['ms_points_comment']   = $pointsPerComment;
        
        if( $calendar->hasChildren( NULL ) === TRUE )
		{
			$level++;
			foreach( $calendar->children( NULL ) AS $child )
			{
				self::populatePermissionMatrix( $rows, $child, $level );
			}
			$level--;
		}
	}
	
	// Create new methods with the same name as the 'do' parameter which should execute it
}