<?php


namespace IPS\membersshop\modules\admin\points;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * donations
 */
class _donations extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		/* Create the table */
		$table = new \IPS\Helpers\Table\Db( 'membersshop_donations', \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=donations' ) );
		$table->langPrefix = 'ms__';

		/* Column stuff */
		$table->include = array( 'id', 'donator_id', 'receiver_id', 'amount', 'time_date' );
		$table->exclude = array( 'id' );
		
				/* Sort stuff */
		$table->sortBy = $table->sortBy ?: 'time_date';
		$table->sortDirection = $table->sortDirection ?: 'desc';
	    $table->noSort	= array( );
		
		$table->parsers = array(
			'time_date'	=> function( $val, $row )
			{
				$date	= \IPS\DateTime::ts( $val );
				return $date->localeDate() . ' ' . $date->localeTime( FALSE ) ;
			},
			'donator_id' => function( $val, $row )
			{
				$donator_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['donator_id'] . "'>$donator_id->name</a>";
				
			},
			'receiver_id' => function( $val, $row )
			{
				$receiver_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['receiver_id'] . "'>$receiver_id->name</a>";
			},
			'amount' => function( $val, $row )
			{
				$amount = number_format($val);
				return $amount;
			},
		);
		
		\IPS\Output::i()->sidebar['actions']['settings'] = array(
			'primary'	=> true,
			'icon'		=> 'cogs',
			'title'		=> 'ms_settings',
			'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=donations&do=settings' )->csrf(),
			'data'		=> array( 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('ms_settings') )
		);
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'ms_donations' );
		\IPS\Output::i()->output	= (string) $table;
	}
	
	protected function settings()
	{
		$pointsName = \IPS\Settings::i()->ms_points_name;
		$form = new \IPS\Helpers\Form;
		$form->addHeader('ms_who_can_donate');
		$form->add( new \IPS\Helpers\Form\Select( 'ms_donate_groups', ( \IPS\Settings::i()->ms_donate_groups == 'all' ) ? 'all' : explode( ',', \IPS\Settings::i()->ms_donate_groups ), TRUE, array( 'options' => \IPS\Member\Group::groups(TRUE, FALSE), 'parse' => 'normal', 'multiple' => true, 'unlimited' => 'all', 'unlimitedLang' => 'all_groups' ), NULL, NULL, NULL, 'ms_donate_groups' ) );
        $form->add( new \IPS\Helpers\Form\Number( 'ms_donate_min', \IPS\Settings::i()->ms_donate_min, TRUE, array( 'min' => 1 ), NULL, NULL, NULL, 'ms_donate_min' ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_donate_max', \IPS\Settings::i()->ms_donate_max, TRUE, array( 'unlimited' => -1 ), NULL, NULL, NULL, 'ms_donate_max' ) );
					
		if( $values = $form->values() )
        {
	        $form->saveAsSettings();
	        \IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=donations' ), 'saved' );
	        return TRUE;
        }
		
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('ms_points', FALSE, array( 'sprintf' => array( $pointsName ) ) );
		\IPS\Output::i()->output = $form;
	}
}