<?php


namespace IPS\membersshop\modules\admin\points;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * downloads
 */
class _downloads extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('module__membersshop_points_downloads');	   
		
		\IPS\Output::i()->sidebar['actions']['misc'] = array(
			'icon'		=> 'superpowers',
			'title'		=> 'ms_misc',
			'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=misc' ),
			'data'		=> array( )
		);	
		
		if( \IPS\Settings::i()->clubs AND !\IPS\Settings::i()->ms_disable_clubs_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['clubs'] = array(
				'icon'		=> 'users',
				'title'		=> 'ms_clubs',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=clubs' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'calendar') AND !\IPS\Settings::i()->ms_disable_calendar_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['calendar'] = array(
				'icon'		=> 'calendar',
				'title'		=> 'ms_calendar',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=calendars' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'gallery') AND !\IPS\Settings::i()->ms_disable_gallery_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['gallery'] = array(
				'icon'		=> 'image',
				'title'		=> 'ms_gallery',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=gallerys' ),
				'data'		=> array( )
			);	
		}
		
		if( \IPS\Application::appIsEnabled( 'forums') AND !\IPS\Settings::i()->ms_disable_forum_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['add'] = array(
				'icon'		=> 'comment-o',
				'title'		=> 'ms_forums',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=forums' ),
				'data'		=> array( )
			);
		}
		
		if( !\IPS\Settings::i()->ms_disable_downloads_hooks )
		{
			\IPS\Output::i()->sidebar['actions']['settings'] = array(
				'primary'	=> true,
				'icon'		=> 'cogs',
				'title'		=> 'ms_settings',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=downloads&do=downloadsettings' ),
				'data'		=> array( 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('ms_settings') )
			);
			
			\IPS\Output::i()->sidebar['actions']['massaddcats'] = array(
				'primary'	=> true,
				'icon'		=> 'plus',
				'title'		=> 'ms_mass_add_download_points',
				'link'		=> \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=downloads&do=massaddpoints' ),
				'data'		=> array( 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('ms_mass_add') )
			);
		}
			
		if( \IPS\Application::appIsEnabled( 'downloads') AND !\IPS\Settings::i()->ms_disable_downloads_hooks )
		{       
	        $matrix = new \IPS\Helpers\Form\Matrix;
        
        	$matrix->manageable = FALSE;
	        $matrix->widths = array( 'label' => 30 );
	        $matrix->langPrefix = 'ms_downloads_';
        
	        $matrix->columns = array(
				'label'	=> function( $key, $value, $data )
				{
					return $value;
				}
			);
                
	        $matrix->columns[ 'ms_points_upload' ] = function( $key, $value, $data ) 
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'uploads_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};                
			$matrix->columns[ 'ms_points_downloads' ] = function( $key, $value, $data )
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'downloads_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};
			$matrix->columns[ 'ms_points_review' ] = function( $key, $value, $data )
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'reviews_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};
			$matrix->columns[ 'ms_points_comment' ] = function( $key, $value, $data )
			{
				return ( \is_null( $value ) ) ? NULL : new \IPS\Helpers\Form\Number( 'comments_'.$key, $value, FALSE, array( 'disabled' => (bool) \is_null( $value ) ) );
			};

	        $rows = array();
		
			foreach( \IPS\downloads\Category::roots( NULL ) AS $root )
			{
				self::populatePermissionMatrix( $rows, $root );
			}
		
			$matrix->rows = $rows;

	        if( $values = $matrix->values() )
   		    {
				if( !empty( $matrix->changedRows ) )
				{
					foreach( $matrix->changedRows as $key )
					{
						try
						{
							$points = \IPS\membersshop\Downloads\Points::load( $key, 'cat_id' );
						}
						catch ( \OutOfRangeException $e )
						{
						    $points = new \IPS\membersshop\Downloads\Points;
							$points->cat_id = $key;
						}
						$points->points_for_upload = (int) $values[ $key ]['ms_points_upload'];
						$points->points_for_download = (int) $values[ $key ]['ms_points_downloads'];
						$points->points_for_review = (int) $values[ $key ]['ms_points_review'];
						$points->points_for_comment = (int) $values[ $key ]['ms_points_comment'];
						$points->save();
					}
				}
	        }
			
	        \IPS\Output::i()->output = $matrix;
		}
		else
		{
			\IPS\Output::i()->output = '<div class="ipsPad ipsBox">You must have the downloads app installed and the disable downloads settings switched off to use this feature</div>';
		}
	}
	
	public static function populatePermissionMatrix( &$rows, $downloads, $level=0 )
	{
		$rows[ $downloads->_id ] = array( '_level' => $level, 'label' => $downloads->_title );
        try
		{
			$points = \IPS\membersshop\Downloads\Points::load( $downloads->_id, 'cat_id' );
			$pointsPerUpload = $points->points_for_upload;
			$pointsPerDownload = $points->points_for_download;
			$pointsPerReview = $points->points_for_review;
			$pointsPerComment = $points->points_for_comment;
        }
		catch ( \OutOfRangeException $e )
		{
			$pointsPerUpload = 0;
			$pointsPerDownload = 0;
			$pointsPerReview = 0;
			$pointsPerComment = 0;
		}
		$rows[ $downloads->_id ]['ms_points_upload']   = $pointsPerUpload;
    	$rows[ $downloads->_id ]['ms_points_downloads']   = $pointsPerDownload;
		$rows[ $downloads->_id ]['ms_points_review']   = $pointsPerReview;
		$rows[ $downloads->_id ]['ms_points_comment']   = $pointsPerComment;
        
        if( $downloads->hasChildren( NULL ) === TRUE )
		{
			$level++;
			foreach( $downloads->children( NULL ) AS $child )
			{
				self::populatePermissionMatrix( $rows, $child, $level );
			}
			$level--;
		}
	}
	
	protected function downloadsettings()
	{
		$form = new \IPS\Helpers\Form;
		$form->addMessage('ms_file_cost_desc');
		$form->add( new \IPS\Helpers\Form\Select( 'ms_downloads_paid_groups', ( \IPS\Settings::i()->ms_downloads_paid_groups == 'all' ) ? 'all' : explode( ',', \IPS\Settings::i()->ms_downloads_paid_groups ), TRUE, array( 'options' => \IPS\Member\Group::groups( TRUE, FALSE ), 'parse' => 'normal', 'multiple' => true, 'unlimited' => 'all', 'unlimitedLang' => 'all_groups' ), NULL, NULL, NULL, 'ms_downloads_paid_groups' ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_downloads_commission', \IPS\Settings::i()->ms_downloads_commission, FALSE, array( ), NULL, NULL, '%', 'ms_downloads_commission' ) );
		if( $values = $form->values() )
        {
			$form->saveAsSettings();
	        \IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=downloads' ), 'saved' );
	        return TRUE;
        }
		\IPS\Output::i()->output = $form;
	}
	
	protected function massaddpoints ()
	{
		$form = new \IPS\Helpers\Form;
		$form->addMessage('ms_mass_add_desc');
		$form->add( new \IPS\Helpers\Form\Node( 'ms_download_cats', NULL, TRUE, array( 'class' => 'IPS\downloads\Category', 'multiple' => FALSE ) ) );
		$form->add( new \IPS\Helpers\Form\Number( 'ms_download_cat_mass_add', NULL, TRUE, array( ), NULL, NULL, NULL, 'ms_download_cat_mass_add' ) );
		if( $values = $form->values(TRUE) )
        {
			\IPS\Db::i()->delete( 'membersshop_downloads_files', array( 'file_cat_id=?', $values['ms_download_cats'] ) );
			
			foreach( \IPS\Db::i()->select( '*', 'downloads_files', array( 'file_cat=?', $values['ms_download_cats'] ) ) as $files )
			{
				$file = \IPS\downloads\File::load( $files['file_id'] );
				if( !$file->isPaid() )
				{
					$setPoints = new \IPS\membersshop\Downloads\Files;
					$setPoints->file_id = $file->id;
					$setPoints->points = $values['ms_download_cat_mass_add'];
					$setPoints->file_cat_id = $file->cat;
					$setPoints->save();
				}
			}
				
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=downloads' ), 'saved' );
	    }
		\IPS\Output::i()->output = $form;
	}
}