<?php


namespace IPS\membersshop\modules\admin\points;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * logs
 */
class _logs extends \IPS\Dispatcher\Controller
{
	/**
	 * @brief	Has been CSRF-protected
	 */
	public static $csrfProtected = TRUE;
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		/* Create the table */
		$table = new \IPS\Helpers\Table\Db( 'membersshop_logs', \IPS\Http\Url::internal( 'app=membersshop&module=points&controller=logs' ) );
		$table->langPrefix = 'ms_logs_';

		/* Column stuff */
		$table->include = array( 'member_id', 'note', 'amount', 'points', 'time_date' );
		$table->mainColumn = 'note';
		$table->widths = array( 'member_id' => '12', 'points' => '10', 'time_date' => '15', 'amount' => '10' );
		
		/* Sort stuff */
		$table->sortBy = $table->sortBy ?: 'time_date';
		$table->sortDirection = $table->sortDirection ?: 'DESC';
	    $table->quickSearch = 'note';
		$table->advancedSearch = array(
			'member_id'	=> \IPS\Helpers\Table\SEARCH_MEMBER,
			'time_date'	=> \IPS\Helpers\Table\SEARCH_DATE_RANGE
		);
		
		/* Formatters */
		$table->parsers = array(
			'amount' => function( $val, $row )
			{
				$price = number_format($val);
				if( $row['type'] == 1 )
				{
					return '<span style="color:green">+'.$price.'</span>';
				}
				else
				{
					return '<span style="color:red">-'.$price.'</span>';
				}
			},
			'points' => function( $val, $row )
			{
				$price = number_format( $val );
				return $price;
			},
			'note' => function( $val, $row )
			{
				return '<span data-ipsTruncate data-ipsTruncate-size="2 lines" data-ipsTruncate-type="remove">'.$val.'</span>';
			},
			'time_date' => function( $val, $row )
			{
				$date	= \IPS\DateTime::ts( $val );
				return $date->localeDate() . ' ' . $date->localeTime( FALSE ) ;
			},
			'member_id' => function( $val, $row )
			{
				$member_id = \IPS\Member::load( $val );
				return "<a href='" . \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) . $row['member_id'] . "'>$member_id->name</a>";
				
			}
		);
		
		/* Display */
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'ms_admin_logs' );
		\IPS\Output::i()->output	= (string) $table;
	}
	
	// Create new methods with the same name as the 'do' parameter which should execute it
}