<?php


namespace IPS\membersshop\modules\front\logs;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * logs
 */
class _logs extends \IPS\Dispatcher\Controller
{
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		\IPS\Output::i()->globalControllers[] = 'membersshop.shop';
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'membersshop.css', 'membersshop', 'front' ) );
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'global_shop.js', 'membersshop', 'global' ) );
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		$member = \IPS\Member::loggedIn();
		
		$url = \IPS\Http\Url::internal( 'app=membersshop&module=logs&controller=logs', 'front', 'logs' );
		
		$filterArray = array();
		$tableWhere = array();
		
		$filterArray['my_logs'] = array( 'member_id=?', $member->member_id );
		$filterArray['ms_filter_items'] = array( -1, -2, -3, -4, -5, -6, -7, -8, -9, -10, -11, -12, -13, -14, -15, -20, -21, -22, 5, 16, 17, 10, 21, -999 );
		$filterArray['ms_filter_point_items'] = array( 5, 10, 21 );
		if( \IPS\Application::appIsEnabled( 'forums' ) )
		{
			$filterArray['ms_filter_forums'] = array( -2, -3, -4, -15 );
		}
		if( \IPS\Application::appIsEnabled( 'downloads' ) )
		{
			$filterArray['ms_filter_downloads']	= array( -5,-6,-7,-8 );
		}
		if( \IPS\Application::appIsEnabled( 'gallery' ) )
		{
			$filterArray['ms_filter_gallery'] = array( -20,-21,-22 );
		}
		if( \IPS\Application::appIsEnabled( 'calendar' ) )
		{
			$filterArray['ms_filter_calendar'] = array( -9,-10,-11 );
		}
		if( \IPS\Application::appIsEnabled( 'nexus' ) )
		{
			$filterArray['ms_filter_nexus']	= array( -14 );
		}
		if( \IPS\Application::appIsEnabled( 'rules' ) )
		{
			$filterArray['ms_filter_rules']	= array( -999 );
		}
		$filterArray['ms_filter_statuses']	= array( -12,-13 );
		$filterArray['ms_filter_reactions']	= array( -1 );
		
		if( \IPS\Request::i()->filterBy )
		{
			foreach( $filterArray as $k => $v )
			{
				if( \IPS\Request::i()->filterBy == $k )
				{
					$url = $url->setQueryString( 'filterBy', $k );
					if( \IPS\Request::i()->filterBy == 'ms_filter_items' )
					{
						$tableWhere = array( \IPS\Db::i()->in( 'item_id', $v, TRUE ) );
					}
					elseif( \IPS\Request::i()->filterBy == 'my_logs' )
					{
						$tableWhere = $v;
					}
					else
					{
						$tableWhere = array( \IPS\Db::i()->in( 'item_id', $v, FALSE ) );
					}
				}
			}
		}
		
		$table = new \IPS\Helpers\Table\Db( 'membersshop_rewards', $url, $tableWhere );
		if( \IPS\Settings::i()->ms_logs_view_set == 0 )
		{
			$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('logs', 'membersshop'), 'rows' );
		}
		else
		{
			if( \IPS\Settings::i()->ms_grid_style == 0 )
			{
				$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('logs', 'membersshop'), 'rowsGridMini' );
			}
			else
			{
				$table->rowsTemplate = array( \IPS\Theme::i()->getTemplate('logs', 'membersshop'), 'rowsGrid' );
			}
		}
		$table->langPrefix = 'ms__';
		$table->limit = \IPS\Settings::i()->ms_rewards_table_limit;
		$table->title = 'ms_RewardsNlogs';		
		
		$table->sortBy = $table->sortBy ?: 'time_date';
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( array(
				'contents' 	=> \IPS\Theme::i()->getTemplate( 'logs' )->template( (string) $table ),
				'sidebar'	=> \IPS\Theme::i()->getTemplate( 'logs' )->indexSidebar( $url, $filterArray )
			)) ;
			return;
		}
		else
		{
			\IPS\Output::i()->sidebar['contextual'] = \IPS\Theme::i()->getTemplate( 'logs' )->indexSidebar( $url, $filterArray );
			\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('ms_RewardsNlogs');
			\IPS\Output::i()->breadcrumb['module'] = array( \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=main', 'front', 'membersshop' ), \IPS\Member::loggedIn()->language()->addToStack('__app_membersshop') );
			\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack('ms_logs') );
			\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('logs', 'membersshop')->template( (string) $table );
		}
	}
	
	protected function rewardLog()
	{
		$id  = \intval( \IPS\Request::i()->id );
		$rewardLog = \IPS\membersshop\Rewards::load( $id );
		$reward = sprintf( \IPS\Member::loggedIn()->language()->get( 'ms_log_posts' ), $rewardLog->reward, $rewardLog->name  );
		\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'logs', 'membersshop' )->rewardLog( $reward );
	}
}