<?php

namespace IPS\membersshop\modules\front\stats;

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * main
 */
class _main extends \IPS\Dispatcher\Controller
{
	public function execute()
	{
		\IPS\Output::i()->jsVars['ms_flash_msg_pos'] = \IPS\Settings::i()->ms_flash_msg_pos;
		\IPS\Output::i()->globalControllers[] = 'membersshop.shop';
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'global_shop.js', 'membersshop', 'global' ) );
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'membersshop.css', 'membersshop', 'front' ) );
		parent::execute();
	}
	 
	protected function manage()
	{
		$pointsName = \IPS\Settings::i()->ms_points_name;
		$chart = new \IPS\Helpers\Chart\Database( \IPS\Http\Url::internal( "app=membersshop&module=stats&controller=main", 'front', 'stats' ), 'membersshop_rewards', 'time_date', '', array( 
			'isStacked' => FALSE,
			'backgroundColor' 	=> '#ffffff',
			'colors'			=> array( '#10967e', '#ea7963', '#de6470' ),
			'lineWidth'			=> 1,
			'areaOpacity'		=> 0.4
		), 
			'AreaChart',
			'daily' 
		);
		$chart->addSeries( \IPS\Member::loggedIn()->language()->addToStack('ms_stats_points_gained', FALSE, array( 'sprintf' => array( $pointsName ) ) ), 'number', 'SUM(reward)', FALSE );
		$chart->availableTypes = array( 'AreaChart', 'LineChart', 'ColumnChart', 'BarChart' );
		$chart->where = array( 'item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=?', 5, 10, 16, 17, 21, -1, -2, -3, -4, -5, -6  );
		
		if( \IPS\Request::i()->noheader )
		{
			\IPS\Output::i()->output = (string) $chart;
			return;
		}
		
		$pieChart = new \IPS\Helpers\Chart;
		$pieChart->addHeader( "Member Group", 'string' );
		$pieChart->addHeader( "Points", 'number' );
		
		foreach( \IPS\Db::i()->select( 'g_id', 'core_groups', 'g_id IS NOT NULL AND g_id!=2' ) as $gName )
		{
			try
			{
			    $bankSum = \IPS\Db::i()->select( 'SUM(points)', 'membersshop_bank', array( 'm_group_id=?', $gName ) )->first();
			}
			catch( \Exception $ex )
			{
				$bankSum = 0;
			}
			$handSum = 0;
			foreach( \IPS\Db::i()->select( '*', 'membersshop_points', array( 'id IS NOT NULL' ) ) as $members )
			{
				$member = \IPS\Member::load( $members['member_id'] );
				if( $member->inGroup( $gName ) )
				{
					$handSum = $handSum + $member->shopPoints();
				}
			}
			$sum = $bankSum + $handSum;
			if( $sum < 0 ){ $sum = 0; }
			$group = \IPS\Member\Group::load( $gName )->name;
		    $pieChart->addRow( array( $group, $sum ) );
		}
		
		$limit = 10;
		$number = 1;
		
		$mostPointsSort = 'membersshop_points.points DESC';
		
		$mostPoints = \IPS\Db::i()->select(
			'*',
			'membersshop_points',
			'member_id',
			$mostPointsSort,
			$limit
		);

		
		$mostPointsGained = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'reward' ), 'membersshop_rewards', array( 'item_id=? or item_id=? or item_id=? or item_id=? or item_id=? or item_id=?', -1, -2, -3, -4, -5, -6 ) ) as $rep )
		{
			try
			{
				$getMember = \IPS\Member::load( $rep['member_id'] );
				if( $getMember->completed )
				{
					if( !isset( $mostPointsGained[ $rep['member_id'] ] ) )
					{
						$mostPointsGained[ $rep['member_id'] ] = $rep['reward'];
					}
					else
					{
						$mostPointsGained[ $rep['member_id'] ] += $rep['reward'];
					}
				}
			}
			catch( \Exception $ex ){}
			
		}
		arsort( $mostPointsGained );
		$mostPointsGained = \array_slice( $mostPointsGained, 0, $limit, TRUE );
		
		$mostRewards = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'reward' ), 'membersshop_rewards', array( 'item_id IS NOT NULL' ) ) as $rep )
		{
			try
			{
				$getMember = \IPS\Member::load( $rep['member_id'] );
				if( $getMember->completed )
				{
					if( !isset( $mostRewards[ $rep['member_id'] ] ) )
					{
						$mostRewards[ $rep['member_id'] ] = $number;
					}
					else
					{
						$mostRewards[ $rep['member_id'] ] += $number;
					}
				}
			}
			catch( \Exception $ex ){}
		}
		arsort( $mostRewards );
		$mostRewards = \array_slice( $mostRewards, 0, $limit, TRUE );
		
		\IPS\Output::i()->sidebar['enabled'] = FALSE;
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'admin.js', 'global' ) );
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'membersshop.css', 'membersshop', 'global' ) );
		\IPS\Output::i()->breadcrumb['module'] = array( \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=main', 'front', 'membersshop' ), \IPS\Member::loggedIn()->language()->addToStack('__app_membersshop') );
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_main_stats' ) );
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'ms_members_shop_stats' );
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( array(
				'contents' 	=> \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->points( $chart, $limit, $mostPoints, $mostPointsGained, $mostRewards, $pieChart->render( 'PieChart', array(
					'title'	=> "",
					'is3D'	=> TRUE,
					'backgroundColor' => '#ffffff',
					'chartArea' => array( 
						'width' =>"90%", 
						'height' => "90%"
					) 
				)) )
			));
			return;
		}
		else
		{
			\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->points( $chart, $limit, $mostPoints, $mostPointsGained, $mostRewards, $pieChart->render( 'PieChart', array(
				'title'	=> "",
				'is3D'	=> TRUE,
				'backgroundColor' => '#ffffff',
				'chartArea' => array( 
					'width' =>"90%", 
					'height' => "90%"
				) 
			)) );
		}
	}
	
	protected function shopitems()
	{
		$pointsName = \IPS\Settings::i()->ms_points_name;
		
		$chart = new \IPS\Helpers\Chart\Database( \IPS\Http\Url::internal( "app=membersshop&module=stats&controller=main&do=shopitems", 'front', 'stats_shop' ), 'membersshop_purchases', 'time_date', '', array( 
			'isStacked' => FALSE,
			'backgroundColor' 	=> '#ffffff',
			'colors'			=> array( '#10967e', '#ea7963' ),
			'hAxis'				=> array( 'gridlines' => array( 'color' => '#f5f5f5' ) ),
			'lineWidth'			=> 1,
			'areaOpacity'		=> 0.4
		), 
			'AreaChart',
			'daily' 
		);
		
		$chart->addSeries( \IPS\Member::loggedIn()->language()->addToStack('ms_stats_spent', FALSE, array( 'sprintf' => array( $pointsName ) ) ), 'number', 'SUM(price)', FALSE );
		$chart->addSeries( \IPS\Member::loggedIn()->language()->addToStack( 'ms_stats_purchases' ), 'number', 'COUNT(*)', FALSE );
		$chart->availableTypes = array( 'AreaChart', 'LineChart', 'ColumnChart', 'BarChart' );
		
		if( \IPS\Request::i()->noheader )
		{
			\IPS\Output::i()->output = (string) $chart;
			return;
		}
		
		$pieChart = new \IPS\Helpers\Chart;
		$pieChart->addHeader( "Item", 'string' );
		$pieChart->addHeader( "Purchases", 'number' );
		
		foreach( \IPS\Db::i()->select( '*', 'membersshop_items', 'id IS NOT NULL AND open=1' ) as $items )
		{
			try
			{
				$item = \IPS\membersshop\Items::load( $items['id'] );
				$sum = \IPS\Db::i()->select( 'COUNT(*)', 'membersshop_purchases', array( 'item_id=?', $item->id ) )->first();
				$pieChart->addRow( array( $item->name, $sum ) );
			}
			catch( \Exception $ex ){}
		}
		
		$limit = 10;
		$number = 1;
		$mostPurchases = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'id' ), 'membersshop_purchases', array( 'member_id>0', ) ) as $rep )
		{
			if( !isset( $mostPurchases[ $rep['member_id'] ] ) )
			{
				$mostPurchases[ $rep['member_id'] ] = $number;
			}
			else
			{
				$mostPurchases[ $rep['member_id'] ] += $number;
			}
		}
		arsort( $mostPurchases );
		$mostPurchases = \array_slice( $mostPurchases, 0, $limit, TRUE );
		
		$topContributors = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'price' ), 'membersshop_purchases', array( 'member_id>0', ) ) as $rep )
		{
			if( !isset( $topContributors[ $rep['member_id'] ] ) )
			{
				$topContributors[ $rep['member_id'] ] = $rep['price'];
			}
			else
			{
				$topContributors[ $rep['member_id'] ] += $rep['price'];
			}
		}
		arsort( $topContributors );
		$topContributors = \array_slice( $topContributors, 0, $limit, TRUE );
		

		$mostSent = array();
		foreach( \IPS\Db::i()->select( array( 'sender_id', 'id' ), 'membersshop_sent_items', array( 'sender_id>0', ) ) as $rep )
		{
			if( !isset( $mostSent[ $rep['sender_id'] ] ) )
			{
				$mostSent[ $rep['sender_id'] ] = $number;
			}
			else
			{
				$mostSent[ $rep['sender_id'] ] += $number;
			}
		}
		arsort( $mostSent );
		$mostSent = \array_slice( $mostSent, 0, $limit, TRUE );
		
		\IPS\Output::i()->sidebar['enabled'] = FALSE;
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'admin.js', 'global' ) );
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'membersshop.css', 'membersshop', 'global' ) );
		\IPS\Output::i()->breadcrumb['module'] = array( \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=main', 'front', 'membersshop' ), \IPS\Member::loggedIn()->language()->addToStack('__app_membersshop') );
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_shop_stats' ) );
		
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'ms_members_shop_stats' );
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( array(
				'contents' 	=> \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->shop( $chart, $mostPurchases, $limit, $topContributors, $mostSent, $pieChart->render( 'PieChart', array(
					'title'	=> "",
					'is3D'	=> TRUE,
					'backgroundColor' => '#ffffff',
					'chartArea' => array( 
						'width' =>"90%", 
						'height' => "90%"
					) 
				)) )
			));
			return;
		}
		else
		{
			\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->shop( $chart, $mostPurchases, $limit, $topContributors, $mostSent, $pieChart->render( 'PieChart', array(
				'title'	=> "",
				'is3D'	=> TRUE,
				'backgroundColor' => '#ffffff',
				'chartArea' => array( 
					'width' =>"90%", 
					'height' => "90%"
				) 
			)) );
		}
	}
	
	protected function rewards()
	{
		$pointsName = \IPS\Settings::i()->ms_points_name;
		$chart = new \IPS\Helpers\Chart\Database( \IPS\Http\Url::internal( "app=membersshop&module=stats&controller=main&do=rewards", 'front', 'stats_rewards' ), 'membersshop_rewards', 'time_date', '', array( 
			'isStacked' => FALSE,
			'backgroundColor' 	=> '#ffffff',
			'colors'			=> array( '#10967e', '#ea7963', '#de6470' ),
			'hAxis'				=> array( 'gridlines' => array( 'color' => '#f5f5f5' ) ),
			'lineWidth'			=> 1,
			'areaOpacity'		=> 0.4
		), 
			'AreaChart',
			'daily' 
		);
		
		$chart->addSeries( \IPS\Member::loggedIn()->language()->addToStack('ms_stats_points_won', FALSE, array( 'sprintf' => array( $pointsName ) ) ), 'number', 'SUM(reward)', FALSE );
		$chart->addSeries( \IPS\Member::loggedIn()->language()->addToStack('ms_stats_boxes_opened'), 'number', 'count(*)', FALSE );
		$chart->availableTypes = array( 'AreaChart', 'LineChart', 'ColumnChart', 'BarChart' );
		$chart->where = array( 'item_id=? or item_id=? or item_id=? or item_id=? or item_id=?', 5, 10, 16, 17, 21 );
		
		if( \IPS\Request::i()->noheader )
		{
			\IPS\Output::i()->output = (string) $chart;
			return;
		}
		
		$pieChart = new \IPS\Helpers\Chart;
		$pieChart->addHeader( "Points", 'string' );
		$pieChart->addHeader( "Points", 'number' );
		$won = \IPS\Db::i()->select( 'SUM(reward)', 'membersshop_rewards', array( 'item_id=? or item_id=? or item_id=? or item_id=? or item_id=?', 5, 10, 16, 17, 21 ) )->first();
		$spent = \IPS\Db::i()->select( 'SUM(price)', 'membersshop_purchases', array( 'item_id=? or item_id=? or item_id=? or item_id=? or item_id=?', 5, 10, 16, 17, 21 ) )->first();
		$pieChart->addRow( array( 'Points Won', $won ) );
		$pieChart->addRow( array( 'Points Spent', $spent ) );
		
		$limit = 10;
		$number = 1;
		
		$topPointsWinner = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'reward' ), 'membersshop_rewards', array( 'item_id=5 or item_id=10 or item_id=16 or item_id=17 or item_id=21', ) ) as $rep )
		{
			if( !isset( $topPointsWinner[ $rep['member_id'] ] ) )
			{
				$topPointsWinner[ $rep['member_id'] ] = $rep['reward'];
			}
			else
			{
				$topPointsWinner[ $rep['member_id'] ] += $rep['reward'];
			}
		}
		arsort( $topPointsWinner );
		$topPointsWinner = \array_slice( $topPointsWinner, 0, $limit, TRUE );
		
		
		$BroughtMostItemsForPoints = array();
		foreach( \IPS\Db::i()->select( array( 'member_id', 'reward' ), 'membersshop_rewards', array( 'item_id=5 or item_id=10 or item_id=16 or item_id=17 or item_id=21', ) ) as $rep )
		{
			if( !isset( $BroughtMostItemsForPoints[ $rep['member_id'] ] ) )
			{
				$BroughtMostItemsForPoints[ $rep['member_id'] ] = $number;
			}
			else
			{
				$BroughtMostItemsForPoints[ $rep['member_id'] ] += $number;
			}
		}
		arsort( $BroughtMostItemsForPoints );
		$BroughtMostItemsForPoints = \array_slice( $BroughtMostItemsForPoints, 0, $limit, TRUE );
		
		$LatestrewardedPoints = \IPS\Db::i()->select( '*', 'membersshop_rewards', array( 'item_id=5 or item_id=10 or item_id=16 or item_id=17', ), 'time_date DESC', $limit);
		
		\IPS\Output::i()->sidebar['enabled'] = FALSE;
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'admin.js', 'global' ) );
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'membersshop.css', 'membersshop', 'global' ) );
		\IPS\Output::i()->breadcrumb['module'] = array( \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=main', 'front', 'membersshop' ), \IPS\Member::loggedIn()->language()->addToStack('__app_membersshop') );
		\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack( 'ms_gamble_stats' ) );
		
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'ms_members_shop_stats' );
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( array(
				'contents' 	=> \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->rewards( $chart, $topPointsWinner, $limit, $BroughtMostItemsForPoints, $LatestrewardedPoints, $pieChart->render( 'PieChart', array(
					'title'	=> "",
					'is3D'	=> TRUE,
					'backgroundColor' => '#ffffff',
					'chartArea' => array( 
						'width' =>"90%", 
						'height' => "90%"
					) 
				)) )
			));
			return;
		}
		else
		{
			\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'stats', 'membersshop' )->rewards( $chart, $topPointsWinner, $limit, $BroughtMostItemsForPoints, $LatestrewardedPoints, $pieChart->render( 'PieChart', array(
				'title'	=> "",
				'is3D'	=> TRUE,
				'backgroundColor' => '#ffffff',
				'chartArea' => array( 
					'width' =>"90%", 
					'height' => "90%"
				) 
			)) );
		}
	}
}