<?php

namespace IPS\membersshop;

if( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
    header( ( isset( $_SERVER[ 'SERVER_PROTOCOL' ] ) ? $_SERVER[ 'SERVER_PROTOCOL' ] :
			'HTTP/1.0' ) . ' 403 Forbidden' );
    exit;
}

class _Shopitems extends \IPS\Content\Item implements 
\IPS\Content\Featurable, 
\IPS\Content\Shareable, 
\IPS\Content\Embeddable
{
	protected static $multitons;
	public static $databaseTable = 'membersshop_items';
	public static $title = 'ms_members_shop';
	public static $icon = 'shopping-basket';
	public static $application = 'membersshop';
	public static $module = 'shop';
	public static $databasePrefix = '';
	public static $databaseColumnId = 'id';
	public static $parentNodeColumnId = 'cat_id';
	public static $containerNodeClass = 'IPS\membersshop\Categories';

	public static $databaseColumnMap = array(
		'container'				=> 'cat_id',
		'author'				=> 'member',
		'content'				=> 'desc',
		'title'					=> 'name',
		'date'					=> 'submitted',
		'featured'				=> 'featured',
	);

	public static function contentTableTemplate()
	{
		return array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop', 'front' ), 'rows' );
	}

	public static function getItemsWithPermission( $where=array(), $order=NULL, $limit=10, $permissionKey='read', $includeHiddenItems=\IPS\Content\Hideable::FILTER_AUTOMATIC, $queryFlags=0, \IPS\Member $member=NULL, $joinContainer=FALSE, $joinComments=FALSE, $joinReviews=FALSE, $countOnly=FALSE, $joins=NULL, $skipPermission=FALSE, $joinTags=TRUE, $joinAuthor=TRUE, $joinLastCommenter=TRUE, $showMovedLinks=FALSE )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		$where[] = "( groups_view='*' OR " . \IPS\Db::i()->findInSet( 'groups_view', $member->groups ) . ' )';
		$where[] = array( 'open=?', 1 );
		$return = parent::getItemsWithPermission( $where, $order, $limit, $permissionKey, $includeHiddenItems, $queryFlags, $member, $joinContainer, $joinComments, $joinReviews, $countOnly, $joins, $skipPermission, $joinTags, $joinAuthor, $joinLastCommenter, $showMovedLinks );
		return $return;
	}

	protected $_url	= array();
	public function url( $action=NULL )
	{
		$_key	= md5( $action );

		if( !isset( $this->_url[ $_key ] ) )
		{
			$this->_url[ $_key ] = \IPS\Http\Url::internal( "app=membersshop&module=shop&controller=view&id={$this->id}", 'front', 'membersshop_items', \IPS\Http\Url\Friendly::seoTitle( $this->name ) );
		
			if( $action )
			{
				$this->_url[ $_key ] = $this->_url[ $_key ]->setQueryString( 'do', $action );
			}
		}

		return $this->_url[ $_key ];
	}

	public function canMove( $member=NULL )
	{
		return FALSE;
	}

	public function canFeature( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();

		if( !$member->modPermission( "ms_mod_feature" ) )
		{
			return FALSE;
		}

		return parent::canFeature( $member );
	}

	public function canUnfeature( $member=NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();

		if( $member->modPermission( "ms_mod_feature" ) )
		{
			return TRUE;
		}

		return parent::canUnfeature( $member );
	}

	public function canDelete( $member=NULL )
	{
		return FALSE;
	}

	public function canEdit( $member=NULL )
	{
		return FALSE;
	}

	public function embedIcon()
	{
		$icon = \IPS\Db::i()->select( 'icon', 'membersshop_items', array( 'id=?', $this->id ) )->first();

		return $icon;
	}

	public function embedContent( $params )
	{
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'embed.css', 'forums', 'front' ) );
		return \IPS\Theme::i()->getTemplate( 'global', 'membersshop' )->embedItem( $this, $this->url()->setQueryString( $params ), $this->embedIcon() );
	}

	public function getImages()
	{
		return \IPS\Db::i()->select( '*', 'membersshop_item_images', array( 'item_id=?', $this->id ) );
	}
	
	public function firstImage()
	{
		if( \count( $this->getImages() ) )
		{
			return \IPS\Db::i()->select( '*', 'membersshop_item_images', array( 'item_id=?', $this->id ) )->first();
		}
		else
		{
			return FALSE;
		}
	}
	
	public function hasSettings()
	{
		if( \in_array( $this->item_id, array( 3, 4, 6, 8, 9, 10, 19, 21, 22, 23, 24, 25, 200, 1570989360 ) ) )
		{
			return TRUE;
		}
		return FALSE;
	}
	
	public function usePopup()
	{
		return FALSE;
	}
}